@@ -7,9 +7,8 @@ from urduhack.tokenization import sentence_tokenizer, word_tokenizer
 from ..parser import Parser
 
 
-# class for running the tokenizer
 class TokenizeParser(Parser):
-    """Test"""
+    """Parser covert Urdu text into sentences and words."""
 
     def _set_up(self, config):
         """pass"""
@@ -17,12 +16,16 @@ class TokenizeParser(Parser):
     def _tokenized_text(self, text):
         """generate dictionary data structure"""
 
-        document = []
+        doc: list = []
+        conll_format: list = []
         sentences = sentence_tokenizer(text)
         idx = 0
 
         for sentence in sentences:
+
             words = word_tokenizer(sentence)
+            doc.append(" ".join(words))
+
             sent = []
             for token_id, token in enumerate(words):
                 sent.append({CoNLL.ID: str(token_id + 1),
@@ -30,11 +33,11 @@ class TokenizeParser(Parser):
                              CoNLL.MISC: f'start_char={idx}|end_char={idx + len(token)}'})
                 idx += len(token) + 1
 
-            document.append(({}, sent))
+            conll_format.append(({}, sent))
 
-        return document
+        return conll_format, " ".join(doc)
 
     def parse(self, document):
-        """pass"""
-        conll_data = self._tokenized_text(document)
-        return Document(conll_data, document)
+        """Generate sentences and words"""
+        conll_data, doc = self._tokenized_text(document)
+        return Document(conll_data, doc)
