@@ -13,6 +13,6 @@ def download():
     download_from_url(file_name=file_name, url=_url, download_dir='models/tokenizer/word/v1')
 
     # Sentiment model
-    _url = MODELS_URL['SENTIMENT_V1_WEIGHTS']
-    file_name = _url.split("/")[-1]
-    download_from_url(file_name=file_name, url=_url, download_dir='models/sentiment/v1')
+    # _url = MODELS_URL['SENTIMENT_V1_WEIGHTS']
+    # file_name = _url.split("/")[-1]
+    # download_from_url(file_name=file_name, url=_url, download_dir='models/sentiment/v1')
